Learn R Programming

isocat (version 0.3.0)

cumsumbelow: Cumulative sum below value

Description

Function that calculates the cumulative sum of values less than or equal to a given value.

Usage

cumsumbelow(vals)

Value

Returns list of values representing cumulative sum of `val` values less than or equal to the input.

Arguments

vals

Object of numeric or integer class.

Examples

Run this code
vals <- 1:10
cumsumbelow(vals)

Run the code above in your browser using DataLab