powered by
Function that calculates the cumulative sum of values less than or equal to a given value.
cumsumbelow(vals)
Returns list of values representing cumulative sum of `val` values less than or equal to the input.
Object of numeric or integer class.
vals <- 1:10 cumsumbelow(vals)
Run the code above in your browser using DataLab